==> flutter_ads-0.1.0.tar.gz: ios/Classes/FlutterAdsSplashView.m <==
//
//  FlutterAdsSplashView.m
//  Runner
//
//  Created by 彭新凯 on 2019/11/18.
//  Copyright © 2019 The Chromium Authors. All rights reserved.
//

#import "FlutterAdsSplashView.h"
#import "GDTSplashAd.h"

@interface FlutterAdsSplashView ()<GDTSplashAdDelegate>
@property (nonatomic, strong) GDTSplashAd *splashAD;
@end
@implementation FlutterAdsSplashView {
    int64_t _viewId;
    UIView * _splashView;
    NSString *gdtAppID;
    NSString *placementID;
    //消息回调
//    FlutterMethodChannel* _channel;
    FlutterBasicMessageChannel *_channel;
}

- (instancetype)initWithWithFrame:(CGRect)frame viewIdentifier:(int64_t)viewId arguments:(id)args binaryMessenger:(NSObject<FlutterBinaryMessenger> *)messenger{
    if ([super init]) {
        _splashView = [[UIView alloc] initWithFrame:frame];
        _splashView.backgroundColor = [UIColor clearColor];
        // 注册通道
        NSString* channelName = @"plugins.nova.ads.event/splashview";
        _channel = [FlutterBasicMessageChannel messageChannelWithName:channelName binaryMessenger:messenger codec:[FlutterStringCodec sharedInstance]];// 编码方式是个坑
        // 接收参数
        NSDictionary *dic = args;
        gdtAppID = dic[@"gdtAppID"];
        placementID = dic[@"placementID"];

        _viewId = viewId;
        [self loadGDTSplash];
    }
    return self;
}

- (void)loadGDTSplash {
    if (gdtAppID.length == 0
        || placementID.length == 0) {
        return;
    }
    self.splashAD = [[GDTSplashAd alloc] initWithAppId:gdtAppID placementId:placementID];
    self.splashAD.delegate = self;
    self.splashAD.fetchDelay = 5;
    self.splashAD.backgroundImage = nil;
    self.splashAD.backgroundColor = [UIColor clearColor];
    [self.splashAD loadAdAndShowInWindow:[UIApplication sharedApplication].keyWindow withBottomView:nil skipView:nil];
}

- (nonnull UIView *)view {
    return _splashView;
}

#pragma mark - GDTSplashAdDelegate
- (void)splashAdSuccessPresentScreen:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdFailToPresent:(GDTSplashAd *)splashAd withError:(NSError *)error
{
    NSLog(@"%s%@",__FUNCTION__,error);
    [_channel sendMessage:@"finish"];
}

- (void)splashAdExposured:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdClicked:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdApplicationWillEnterBackground:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdWillClosed:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
    
    [_channel sendMessage:@"finish"];
}

- (void)splashAdClosed:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
    self.splashAD = nil;
}

- (void)splashAdWillPresentFullScreenModal:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdDidPresentFullScreenModal:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdWillDismissFullScreenModal:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
    [_channel sendMessage:@"finish"];
}

- (void)splashAdDidDismissFullScreenModal:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

@end

==> flutter_ads-0.1.3.tar.gz: ios/Classes/FlutterAdsSplashView.m <==
//
//  FlutterAdsSplashView.m
//  Runner
//
//  Created by 彭新凯 on 2019/11/18.
//  Copyright © 2019 The Chromium Authors. All rights reserved.
//

#import "FlutterAdsSplashView.h"
#import "GDTSplashAd.h"
#import <NOVRemoteConfig/NOVRemoteConfig-Swift.h>

@interface FlutterAdsSplashView ()<GDTSplashAdDelegate>
@property (nonatomic, strong) GDTSplashAd *splashAD;
@end
@implementation FlutterAdsSplashView {
    int64_t _viewId;
    UIView * _splashView;
    NSString *gdtAppID;
    NSString *placementID;
    //消息回调
//    FlutterMethodChannel* _channel;
    FlutterBasicMessageChannel *_channel;
}

- (instancetype)initWithWithFrame:(CGRect)frame viewIdentifier:(int64_t)viewId arguments:(id)args binaryMessenger:(NSObject<FlutterBinaryMessenger> *)messenger{
    if ([super init]) {
        _splashView = [[UIView alloc] initWithFrame:frame];
        _splashView.backgroundColor = [UIColor clearColor];
        // 注册通道
        NSString* channelName = @"plugins.nova.ads.event/splashview";
        _channel = [FlutterBasicMessageChannel messageChannelWithName:channelName binaryMessenger:messenger codec:[FlutterStringCodec sharedInstance]];// 编码方式是个坑
        // 接收参数
//        NSDictionary *dic = args;
//        gdtAppID = dic[@"gdtAppID"];
//        placementID = dic[@"placementID"];

        NSDictionary *configs = [[NOVRemoteConfig shared] configs];
        
        NSData *data = [configs[@"pos_ad_appkey"] dataUsingEncoding:NSUTF8StringEncoding];
        NSDictionary *dict_appid = [NSJSONSerialization JSONObjectWithData:data options:0 error:nil];
        NSString *key = dict_appid.allKeys.firstObject;
        gdtAppID = dict_appid.allValues.firstObject;

        NSDictionary *dict_reward = [NSJSONSerialization JSONObjectWithData:[configs[@"pos_ad_splash"] dataUsingEncoding:NSUTF8StringEncoding] options:0 error:nil];
        placementID = dict_reward[key];

        _viewId = viewId;
        [self loadGDTSplash];
    }
    return self;
}

- (void)loadGDTSplash {
    if (gdtAppID.length == 0
        || placementID.length == 0) {
        return;
    }
    self.splashAD = [[GDTSplashAd alloc] initWithAppId:gdtAppID placementId:placementID];
    self.splashAD.delegate = self;
    self.splashAD.fetchDelay = 5;
    self.splashAD.backgroundImage = nil;
    self.splashAD.backgroundColor = [UIColor clearColor];
    [self.splashAD loadAdAndShowInWindow:[UIApplication sharedApplication].keyWindow withBottomView:nil skipView:nil];
}

- (nonnull UIView *)view {
    return _splashView;
}

#pragma mark - GDTSplashAdDelegate
- (void)splashAdSuccessPresentScreen:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdFailToPresent:(GDTSplashAd *)splashAd withError:(NSError *)error
{
    NSLog(@"%s%@",__FUNCTION__,error);
    [_channel sendMessage:@"finish"];
}

- (void)splashAdExposured:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdClicked:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdApplicationWillEnterBackground:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdWillClosed:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
    
    [_channel sendMessage:@"finish"];
}

- (void)splashAdClosed:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
    self.splashAD = nil;
}

- (void)splashAdWillPresentFullScreenModal:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdDidPresentFullScreenModal:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

- (void)splashAdWillDismissFullScreenModal:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
    [_channel sendMessage:@"finish"];
}

- (void)splashAdDidDismissFullScreenModal:(GDTSplashAd *)splashAd
{
    NSLog(@"%s",__FUNCTION__);
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

@end
